You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@river.apache.org by pe...@apache.org on 2013/01/02 06:21:08 UTC

svn commit: r1427655 [31/35] - in /river/jtsk/skunk/qa_refactor/trunk/qa: ./ doc/ src/com/sun/jini/qa/harness/ src/com/sun/jini/test/impl/discoverymanager/ src/com/sun/jini/test/impl/discoveryproviders/ src/com/sun/jini/test/impl/end2end/e2etest/ src/c...

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveredDelay.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveredDelay.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveredDelay.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveredDelay.java Wed Jan  2 05:20:52 2013
@@ -34,12 +34,12 @@ import com.sun.jini.test.share.GroupsUti
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *    <li> one or more "initial" lookup services, each belonging to a finite
- *         set of member groups, and each started during setup, before the
+ *         set of member groups, and each started during construct, before the
  *         test begins execution
  *    <li> one or more "additional" lookup services, each belonging to a finite
  *         set of member groups, and each started after the test has begun
  *         execution, and after the initial lookup services started during
- *         setup have been discovered
+ *         construct have been discovered
  *    <li> one instance of the lookup discovery utility
  *    <li> the lookup discovery utility is configured to discover the
  *         member groups of each lookup service that is to be started
@@ -56,7 +56,7 @@ public class DiscoveredDelay extends Dis
      * <p><ul>
      *    <li> configures the lookup discovery utility to discover the
      *         member groups of each lookup service that was started during
-     *         setup
+     *         construct
      *    <li> starts the multicast discovery process by adding a discovery
      *         listener to the lookup discovery utility
      *    <li> verifies that the lookup discovery utility under test sends
@@ -74,11 +74,11 @@ public class DiscoveredDelay extends Dis
         /* Verify discovery of the initial lookups */
         super.run();
         /* Configure the listener's expected lookups for all the lookups */
-        mainListener.setLookupsToDiscover(allLookupsToStart);
+        mainListener.setLookupsToDiscover(getAllLookupsToStart());
         /* Configure the lookup discovery utility to discover both the initial
          * and the additional lookups
          */
-        String[] additionalGroups = toGroupsArray(addLookupsToStart);
+        String[] additionalGroups = toGroupsArray(getAddLookupsToStart());
         ldToUse.addGroups(additionalGroups);
         logger.log(Level.FINE, "added additional groups to "
                           +"lookup discovery --");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveredStagger.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveredStagger.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveredStagger.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveredStagger.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -52,10 +53,11 @@ public class DiscoveredStagger extends A
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         delayLookupStart = true;
-        super.setup(sysConfig);
-    }//end setup
+        super.construct(sysConfig);
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
@@ -81,25 +83,25 @@ public class DiscoveredStagger extends A
         boolean oldUseFastTimeout = useFastTimeout;
         useFastTimeout = false;
         StaggeredStartThread lookupsThread =
-                                new StaggeredStartThread(1,allLookupsToStart);
+                                new StaggeredStartThread(1, getAllLookupsToStart());
         try {
             /* Start 1st lookup service (so it's up before discovery starts) */
             LocatorGroupsPair pair
-                                 = (LocatorGroupsPair)allLookupsToStart.get(0);
-            int port = (pair.locator).getPort();
+                                 = (LocatorGroupsPair)getAllLookupsToStart().get(0);
+            int port = (pair.getLocator()).getPort();
             if(portInUse(port)) port = 0;//use randomly chosen port
-            startLookup(0, port, pair.locator.getHost());
+            startLookup(0, port, pair.getLocator().getHost());
             /* Re-configure LookupDiscovery to discover given  groups */
             logger.log(Level.FINE,
                           "change LookupDiscovery to discover -- ");
-            String[] groupsToDiscover = toGroupsArray(allLookupsToStart);
+            String[] groupsToDiscover = toGroupsArray(getAllLookupsToStart());
             for(int i=0;i<groupsToDiscover.length;i++) {
                 logger.log(Level.FINE,
                                   "   "+groupsToDiscover[i]);
             }//end loop
             lookupDiscovery.setGroups(groupsToDiscover);
             /* Add the given listener to the LookupDiscovery utility */
-            mainListener.setLookupsToDiscover(allLookupsToStart);
+            mainListener.setLookupsToDiscover(getAllLookupsToStart());
             lookupDiscovery.addDiscoveryListener(mainListener);
             /* Start remaining lookup services in a time-staggered fashion */
             lookupsThread.start();

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryBeginsOnAddGroupsAfterEmpty.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryBeginsOnAddGroupsAfterEmpty.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryEndsOnTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryEndsOnTerminate.java Wed Jan  2 05:20:52 2013
@@ -33,7 +33,7 @@ import net.jini.discovery.LookupDiscover
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *    <li> one or more initial lookup services, each belonging to a finite
- *         set of member groups, started during setup
+ *         set of member groups, started during construct
  *    <li> one or more additional lookup services, each belonging to a finite
  *         set of member groups, to be started after termination of the lookup
  *         discovery utility
@@ -74,7 +74,7 @@ public class DiscoveryEndsOnTerminate ex
          * instance configured to discover BOTH the initial and additional
          * lookup services to be started.
          */
-        String[] groupsToDiscover = toGroupsArray(allLookupsToStart);
+        String[] groupsToDiscover = toGroupsArray(getAllLookupsToStart());
         logger.log(Level.FINE,
                           "starting discovery by creating a "
                           +"LookupDiscovery to discover -- ");
@@ -89,7 +89,7 @@ public class DiscoveryEndsOnTerminate ex
          * operational by verifying that the INITIIAL lookups are
          * discovered.
          */
-        mainListener.setLookupsToDiscover(initLookupsToStart);
+        mainListener.setLookupsToDiscover(getInitLookupsToStart());
         ld.addDiscoveryListener(mainListener);
         waitForDiscovery(mainListener);
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/Equality.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/Equality.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/Equality.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/Equality.java Wed Jan  2 05:20:52 2013
@@ -38,7 +38,7 @@ public class Equality extends AbstractBa
     /** Executes the current test by doing the following:
      * <p>
      *   Compares the instance of <code>LookupDiscovery</code> created during
-     *   setup to itself and to a new instance; and verifies that the
+     *   construct to itself and to a new instance; and verifies that the
      *   <code>equals</code> method returns the appropriate result depending
      *   on the particular instances of <code>LookupDiscovery</code> being
      *   compared.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetGroups.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -56,10 +57,11 @@ public class GetGroups extends Discovere
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         delayLookupStart = true;//don't start lookups, just want config info
-	super.setup(sysConfig);
-    }//end setup
+	super.construct(sysConfig);
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetGroupsAllGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetGroupsAllGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetGroupsAllGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetGroupsAllGroups.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.discovery.DiscoveryGroupManagement;
 
@@ -48,10 +49,11 @@ public class GetGroupsAllGroups extends 
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	groupsToDiscover = DiscoveryGroupManagement.ALL_GROUPS;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class GetGroupsAllGroups
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetGroupsNoGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetGroupsNoGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetGroupsNoGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetGroupsNoGroups.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.discovery.DiscoveryGroupManagement;
 
@@ -48,10 +49,11 @@ public class GetGroupsNoGroups extends G
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	groupsToDiscover = DiscoveryGroupManagement.NO_GROUPS;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class GetGroupsNoGroups
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetRegistrars.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetRegistrars.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetRegistrars.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/GetRegistrars.java Wed Jan  2 05:20:52 2013
@@ -27,6 +27,7 @@ import net.jini.core.discovery.LookupLoc
 import net.jini.core.lookup.ServiceRegistrar;
 
 import java.util.ArrayList;
+import java.util.List;
 
 /**
  * This class verifies that the <code>LookupDiscovery</code> utility
@@ -57,7 +58,7 @@ public class GetRegistrars extends Disco
      * <p><ul>
      *    <li> re-configures the lookup discovery utility to use group
      *         discovery to discover the set of lookup services started during
-     *         setup
+     *         construct
      *    <li> starts the multicast discovery process by adding a listener to
      *         the lookup discovery utility
      *    <li> verifies that the lookup discovery utility under test
@@ -66,7 +67,7 @@ public class GetRegistrars extends Disco
      *    <li> invokes getRegistrars to retrieve the registrars the lookup
      *         discovery utility has currently discovered
      *    <li> compares the registrars returned by getRegistrars with the 
-     *         registrars that were started during setup (and discovered
+     *         registrars that were started during construct (and discovered
      *         by the lookup discovery utility), and verifies that those sets
      *         are the same
      * </ul>
@@ -76,7 +77,7 @@ public class GetRegistrars extends Disco
         super.run();
         logger.log(Level.FINE, "calling getRegistrars ... ");
         ServiceRegistrar[] regs = ldToUse.getRegistrars(); // prepared by lds
-        ArrayList lusList = getLookupListSnapshot("GetRegistrars.run");
+        List lusList = getLookupListSnapshot("GetRegistrars.run");
         logger.log(Level.FINE,
                           "# of lookups started = "+lusList.size()
                           +", # of registrars from LookupDiscovery = "

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorAllChange.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorAllChange.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorAllChange.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorAllChange.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.discovery.DiscoveryGroupManagement;
 
@@ -77,12 +78,13 @@ public class MulticastMonitorAllChange e
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         groupsToDiscover = DiscoveryGroupManagement.ALL_GROUPS;
         alternateReplacements = false;//replace all groups
         useFastTimeout = false;//needs max discovery time for lookup start
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class MulticastMonitorAllChange
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorChange.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorChange.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorChange.td (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorChange.td Wed Jan  2 05:20:52 2013
@@ -2,3 +2,6 @@ testClass=MulticastMonitorChange
 testCategories=lookupdiscovery,lookupdiscovery_spec,speclookupdiscovery
 include0=lookupdiscovery.properties
 include1=com/sun/jini/test/share/reggie3_0.properties
+#testjvmargs=-Xdebug,\
+#-Xrunjdwp:transport=dt_socket+,address=8000+,server=y+,suspend=y,\
+#${testjvmargs}
\ No newline at end of file

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorReplace.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorReplace.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorReplaceNone.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorReplaceNone.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.discovery.DiscoveryGroupManagement;
 
@@ -61,13 +62,14 @@ public class MulticastMonitorReplaceNone
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         replacementGroups = DiscoveryGroupManagement.NO_GROUPS;
-        int N = nLookupServices + nAddLookupServices;
+        int N = getnLookupServices() + getnAddLookupServices();
         nLookupsToReplace = 1 + ( (N-1)/2 );
         if(nLookupsToReplace <= 0) nLookupsToReplace = 1;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class MulticastMonitorReplaceNone
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorStop.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorStop.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorStop.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorStop.java Wed Jan  2 05:20:52 2013
@@ -76,7 +76,7 @@ public class MulticastMonitorStop extend
      * <p><ul>
      *    <li> verifies the lookup discovery mechanism is functional by
      *         using group discovery to discover the lookup services
-     *         started during setup
+     *         started during construct
      *    <li> stops the generation of multicast announcements by each
      *         lookup service, but allows the lookup services to remain
      *         running and reachable

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorStopReplace.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorStopReplace.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorStopReplace.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorStopReplace.java Wed Jan  2 05:20:52 2013
@@ -22,6 +22,7 @@ import com.sun.jini.qa.harness.QAConfig;
 import java.util.logging.Level;
 
 import java.util.ArrayList;
+import java.util.List;
 
 /** This class verifies that the <code>LookupDiscovery</code> utility
  *  monitors the multicast announcements sent from lookup services
@@ -80,7 +81,7 @@ public class MulticastMonitorStopReplace
      * <p><ul>
      *    <li> verifies the lookup discovery mechanism is functional by
      *         using group discovery to discover the lookup services
-     *         started during setup
+     *         started during construct
      *    <li> stops the generation of multicast announcements by each
      *         lookup service, but allows the lookup services to remain
      *         running and reachable
@@ -99,11 +100,11 @@ public class MulticastMonitorStopReplace
         synchronized(mainListener) {
             stopAnnouncements();
             /* Replace current groups with new groups to cause discards */
-            ArrayList locGroupsPairList = replaceMemberGroups();
+            List locGroupsPairList = replaceMemberGroups();
             /* Set the expected discard event info */
             mainListener.setLookupsToDiscover
                                      (locGroupsPairList,
-                                      toGroupsArray(initLookupsToStart));
+                                      toGroupsArray(getInitLookupsToStart()));
         }//end sync(mainListener)
         waitForDiscard(mainListener);
     }//end run

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorTerminate.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorTerminate.java Wed Jan  2 05:20:52 2013
@@ -89,7 +89,7 @@ public class MulticastMonitorTerminate e
      * <p><ul>
      *     <li> verifies the lookup discovery mechanism is functional by
      *          using group discovery to discover the lookup services
-     *          started during setup
+     *          started during construct
      *     <li> stops the generation of multicast announcements by each
      *          lookup service, and makes each lookup service unreachable
      *     <li> verifies that the lookup discovery utility eventually 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveDiscoveryListener.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveDiscoveryListener.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveDiscoveryListener.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveDiscoveryListener.java Wed Jan  2 05:20:52 2013
@@ -36,10 +36,10 @@ import net.jini.discovery.LookupDiscover
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *    <li> one or more lookup services, each belonging to a finite set of
- *         member groups, and each started during setup, before the test
+ *         member groups, and each started during construct, before the test
  *         begins execution
  *    <li> one or more "initial" lookup services, each belonging to a finite
- *         set of member groups, and each started during setup, before the
+ *         set of member groups, and each started during construct, before the
  *         test begins execution
  *    <li> one or more "additional" lookup services, each belonging to a finite
  *         set of member groups, and each started after the listener has been
@@ -87,9 +87,9 @@ public class RemoveDiscoveryListener ext
          * instance configured to discover BOTH the initial and additional
          * lookup services to be started.
          */
-        String[] groupsToDiscover = toGroupsArray(allLookupsToStart);
-        String[] initialGroups    = toGroupsArray(initLookupsToStart);
-        String[] additionalGroups = toGroupsArray(addLookupsToStart);
+        String[] groupsToDiscover = toGroupsArray(getAllLookupsToStart());
+        String[] initialGroups    = toGroupsArray(getInitLookupsToStart());
+        String[] additionalGroups = toGroupsArray(getAddLookupsToStart());
         logger.log(Level.FINE,
                           "create LookupDiscovery to initially "
                           +"discover groups -- ");
@@ -111,13 +111,13 @@ public class RemoveDiscoveryListener ext
          */
         logger.log(Level.FINE,
                       "verifying discovery for initial listener ...");
-        mainListener.setLookupsToDiscover(initLookupsToStart);
+        mainListener.setLookupsToDiscover(getInitLookupsToStart());
         ld.addDiscoveryListener(mainListener);
         waitForDiscovery(mainListener);
 
         logger.log(Level.FINE,
                  "verifying discovery for listener to be removed ...");
-        newListener.setLookupsToDiscover(initLookupsToStart);
+        newListener.setLookupsToDiscover(getInitLookupsToStart());
         ld.addDiscoveryListener(newListener);
         waitForDiscovery(newListener);
 
@@ -154,7 +154,7 @@ public class RemoveDiscoveryListener ext
 
         logger.log(Level.FINE,
                           "verifying events are still being sent ...");
-        mainListener.setLookupsToDiscover(addLookupsToStart);
+        mainListener.setLookupsToDiscover(getAddLookupsToStart());
         waitForDiscovery(mainListener);
 
         logger.log(Level.FINE, "verifying removed listener "

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsAllGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsAllGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsAllGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsAllGroups.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -57,13 +58,14 @@ public class RemoveGroupsAllGroups exten
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         delayLookupStart = true;//don't start lookups, just want config info
-	super.setup(sysConfig);
+	super.construct(sysConfig);
 	newLD = new LookupDiscovery(groupsToDiscover,
 				    sysConfig.getConfiguration());
 	lookupDiscoveryList.add(newLD);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsDups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsDups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsNullElement.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsNullElement.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>removeGroups</code> method, this class verifies
@@ -45,8 +46,8 @@ public class RemoveGroupsNullElement ext
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	/* Change the groups to remove to include some of the groups the
 	 * lookup discovery utility is currently configured to discover
 	 */
@@ -59,7 +60,8 @@ public class RemoveGroupsNullElement ext
 			    +"as expected");
 	doStr = new String("removing groups from lookup discovery --");
 	doFlag = DO_REMOVE;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class RemoveGroupsNullElement
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsRemoveAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsRemoveAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsRemoveNone.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsRemoveNone.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -60,8 +61,8 @@ public class RemoveGroupsRemoveNone exte
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	initGroups = newLD.getGroups();
 	if(    (initGroups != DiscoveryGroupManagement.ALL_GROUPS)
 	       && (initGroups.length != 0) )
@@ -71,7 +72,8 @@ public class RemoveGroupsRemoveNone exte
 		groupsToRemove[i] = new String(initGroups[i]+"_new");
 	    }//end loop
 	}//endif
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsRemoveSome.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsRemoveSome.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsUnsupportedOperation.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsUnsupportedOperation.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -58,10 +59,11 @@ public class RemoveGroupsUnsupportedOper
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         delayLookupStart = true;//don't start lookups, just want config info
-	super.setup(sysConfig);
-    }//end setup
+	super.construct(sysConfig);
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsAllGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsAllGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsNoGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsNoGroups.java Wed Jan  2 05:20:52 2013
@@ -39,12 +39,12 @@ import net.jini.discovery.DiscoveryGroup
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *    <li> one or more "initial" lookup services, each belonging to a finite
- *         set of member groups, and each started during setup, before the
+ *         set of member groups, and each started during construct, before the
  *         test begins execution
  *    <li> one or more "additional" lookup services, each belonging to a finite
  *         set of member groups, and each started after the test has begun
  *         execution, and after the initial lookup services started during
- *         setup have been discovered
+ *         construct have been discovered
  *    <li> one instance of the lookup discovery utility initially configured
  *         to discover the member groups of the initial lookup services
  *    <li> one instance of DiscoveryListener registered with the lookup
@@ -65,7 +65,7 @@ public class SetGroupsNoGroups extends A
      * <p><ul>
      *    <li> configures the lookup discovery utility to discover the
      *         member groups of both the initial lookup services started
-     *         during setup, and the addtional lookup services started below
+     *         during construct, and the addtional lookup services started below
      *    <li> starts the multicast discovery process by adding a discovery
      *         listener to the lookup discovery utility
      *    <li> verifies that group discovery is currently operational by
@@ -85,10 +85,10 @@ public class SetGroupsNoGroups extends A
      * </ul>
      */
     public void run() throws Exception {
-        String[] initGroupsToDiscover = toGroupsArray(initLookupsToStart);
-        String[] allGroupsToDiscover  = toGroupsArray(allLookupsToStart);
+        String[] initGroupsToDiscover = toGroupsArray(getInitLookupsToStart());
+        String[] allGroupsToDiscover  = toGroupsArray(getAllLookupsToStart());
         /* Set the expected groups to discover to be the initial lookups */
-        mainListener.setLookupsToDiscover(initLookupsToStart,
+        mainListener.setLookupsToDiscover(getInitLookupsToStart(),
                                           initGroupsToDiscover);
         logger.log(Level.FINE, "starting discovery, groups "
                                         +"to discover --");
@@ -102,7 +102,7 @@ public class SetGroupsNoGroups extends A
         waitForDiscovery(mainListener);
 
         /* Set expected lookups to be discarded due to discovery halting */
-        mainListener.setLookupsToDiscover(initLookupsToStart,
+        mainListener.setLookupsToDiscover(getInitLookupsToStart(),
                                       DiscoveryGroupManagement.NO_GROUPS);
         logger.log(Level.FINE, "halting discovery, setting "
                           +"groups to discover to NO_GROUPS ...");
@@ -119,7 +119,7 @@ public class SetGroupsNoGroups extends A
         waitForDiscovery(mainListener);
 
         /* Set expected groups after restart to both initial & additional*/
-        mainListener.setLookupsToDiscover(allLookupsToStart,
+        mainListener.setLookupsToDiscover(getAllLookupsToStart(),
                                           allGroupsToDiscover);
         logger.log(Level.FINE, "re-starting discovery, groups "
                                         +"to discover --");

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsNullElement.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsNullElement.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsNullElement.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsNullElement.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>setGroups</code> method, this class verifies
@@ -45,14 +46,15 @@ public class SetGroupsNullElement extend
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	NPEStr = new String("NullPointerException on group replacement "
 			    +"as expected");
 	doStr = new String
 	    ("setting groups in lookup discovery to --");
 	doFlag = DO_SET;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class SetGroupsNullElement
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsReplaceAll.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsReplaceAll.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsReplaceAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsReplaceAll.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>setGroups</code> method, this class verifies
@@ -53,10 +54,11 @@ public class SetGroupsReplaceAll extends
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         changeAll = true;//replace ALL the groups to discover with new groups
-        super.setup(sysConfig);
-    }//end setup
+        super.construct(sysConfig);
+        return this;
+    }//end construct
 
 }//end class SetGroupsReplaceAll
 

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsReplaceSome.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsReplaceSome.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/QATestUtils.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/QATestUtils.java Wed Jan  2 05:20:52 2013
@@ -41,7 +41,7 @@ import java.lang.reflect.InvocationTarge
 
 import com.sun.jini.qa.harness.QAConfig;
 import com.sun.jini.qa.harness.TestException;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 
 import java.util.logging.Logger;
 import java.util.logging.Level;
@@ -51,7 +51,7 @@ import java.util.logging.Level;
  *  member class, and most methods, contained in this class is public 
  *  and static; this class does not need to be instantiated.
  *
- *  @see QATest
+ *  @see QATestEnvironment
  *  @see com.sun.jini.test.spec.lookupservice.QATestRegistrar
  */
 public class QATestUtils {

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/ToStringTest.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/ToStringTest.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/EvntLeaseExpiration.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/EvntLeaseExpiration.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set00;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -86,8 +87,8 @@ public class EvntLeaseExpiration extends
      *  a lease duration that is less than the duration of the service
      *  leases.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	logger.log(Level.FINE, "in setup() method.");
 	listener = new Listener();
         evntLeaseDurMS = 5*QATestUtils.N_MS_PER_SEC;
@@ -102,6 +103,7 @@ public class EvntLeaseExpiration extends
 			   ServiceRegistrar.TRANSITION_MATCH_MATCH,
 			   listener, null, evntLeaseDurMS);
 	evntReg = prepareEventRegistration(evntReg);
+        return this;
     }
 
     /** wait for the event lease to expire and then verify that NO events

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupByClass.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupByClass.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryBeginsOnAddGroupsAfterEmpty.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryBeginsOnAddGroupsAfterEmpty.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -34,7 +35,7 @@ import net.jini.discovery.LookupDiscover
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *   <li> one or more initial lookup services, each belonging to a finite
  *        set of member groups, started during setup
  *   <li> an instance of the lookup discovery utility created by passing
  *        and empty String array (DiscoveryGroupManagement.NO_GROUPS) to
  *        the constructor
@@ -47,7 +48,7 @@ import net.jini.discovery.LookupDiscover
  * If the lookup discovery utility functions as specified, then the
  * listener will receive no events until the <code>addGroups</code> method
  * is called to re-configure the lookup discovery utility to discover
  * the lookup services started during setup.
  */
 public class DiscoveryBeginsOnAddGroupsAfterEmpty extends AbstractBaseTest {
 
@@ -60,10 +61,11 @@ public class DiscoveryBeginsOnAddGroupsA
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
-        groupsToDiscover = toGroupsArray(initLookupsToStart);
-    }//end setup
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
+        groupsToDiscover = toGroupsArray(getInitLookupsToStart());
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
@@ -73,10 +75,10 @@ public class DiscoveryBeginsOnAddGroupsA
      *         and verifies the listener receives no events
      *    <li> depending on the value of <code>addGroups</code>, invokes either
      *         addGroups or setGroups to re-configure the lookup discovery
      *         utility to discover the lookup services started in setup
      *    <li> verifies that the lookup discovery utility under test
      *         sends the expected discovered events, having the expected
      *         contents related to the lookups started in setup
      * </ul>
      */
     public void run() throws Exception {
@@ -101,7 +103,7 @@ public class DiscoveryBeginsOnAddGroupsA
         ld.addDiscoveryListener(mainListener);
         waitForDiscovery(mainListener);
         /* Re-configure the listener to expect events for the lookups
          * started during setup.
          */
         logger.log(Level.FINE, "calling "+methodStr
                           +" to change the groups to discover to -- ");
@@ -117,10 +119,10 @@ public class DiscoveryBeginsOnAddGroupsA
                 }//end loop
             }//endif
         }//endif
-        mainListener.setLookupsToDiscover(initLookupsToStart);
+        mainListener.setLookupsToDiscover(getInitLookupsToStart());
         /* Using either addGroups ore setGroups, re-configure the lookup
          * discovery utility to discover the lookup services started in
-         * setup
+         * construct
          */
         if(addGroups) {
             ld.addGroups(groupsToDiscover);
@@ -34,7 +35,7 @@ import net.jini.discovery.LookupDiscover
  * <p><ul>
  *   <li> one or more initial lookup services, each belonging to a finite
- *        set of member groups, started during setup
+ *        set of member groups, started during construct
  *   <li> an instance of the lookup discovery utility created by passing
  *        and empty String array (DiscoveryGroupManagement.NO_GROUPS) to
@@ -47,7 +48,7 @@ import net.jini.discovery.LookupDiscover
  * listener will receive no events until the <code>addGroups</code> method
  * is called to re-configure the lookup discovery utility to discover
- * the lookup services started during setup.
+ * the lookup services started during construct.
  */
 public class DiscoveryBeginsOnAddGroupsAfterEmpty extends AbstractBaseTest {
@@ -73,10 +75,10 @@ public class DiscoveryBeginsOnAddGroupsA
      *    <li> depending on the value of <code>addGroups</code>, invokes either
      *         addGroups or setGroups to re-configure the lookup discovery
-     *         utility to discover the lookup services started in setup
+     *         utility to discover the lookup services started in construct
      *    <li> verifies that the lookup discovery utility under test
      *         sends the expected discovered events, having the expected
@@ -73,10 +75,10 @@ public class DiscoveryBeginsOnAddGroupsA
      *    <li> verifies that the lookup discovery utility under test
      *         sends the expected discovered events, having the expected
-     *         contents related to the lookups started in setup
+     *         contents related to the lookups started in construct
      * </ul>
      */
@@ -101,7 +103,7 @@ public class DiscoveryBeginsOnAddGroupsA
         waitForDiscovery(mainListener);
         /* Re-configure the listener to expect events for the lookups
-         * started during setup.
+         * started during construct.
          */
         logger.log(Level.FINE, "calling "+methodStr

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryBeginsOnSetGroupsAfterEmpty.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryBeginsOnSetGroupsAfterEmpty.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryBeginsOnSetGroupsAfterEmpty.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryBeginsOnSetGroupsAfterEmpty.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * This class verifies that the <code>LookupDiscovery</code> utility
@@ -30,7 +31,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *   <li> one or more initial lookup services, each belonging to a finite
  *        set of member groups, started during setup
  *   <li> an instance of the lookup discovery utility created by passing
  *        and empty String array (DiscoveryGroupManagement.NO_GROUPS) to
  *        the constructor
@@ -43,7 +44,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * If the lookup discovery utility functions as specified, then the
  * listener will receive no events until the <code>setGroups</code> method
  * is called to re-configure the lookup discovery utility to discover
  * the lookup services started during setup.
  */
 public class DiscoveryBeginsOnSetGroupsAfterEmpty
                                   extends DiscoveryBeginsOnAddGroupsAfterEmpty
@@ -52,10 +53,11 @@ public class DiscoveryBeginsOnSetGroupsA
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         addGroups = false;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class DiscoveryBeginsOnSetGroupsAfterEmpty
 
@@ -30,7 +31,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * <p><ul>
  *   <li> one or more initial lookup services, each belonging to a finite
- *        set of member groups, started during setup
+ *        set of member groups, started during construct
  *   <li> an instance of the lookup discovery utility created by passing
  *        and empty String array (DiscoveryGroupManagement.NO_GROUPS) to
@@ -43,7 +44,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * listener will receive no events until the <code>setGroups</code> method
  * is called to re-configure the lookup discovery utility to discover
- * the lookup services started during setup.
+ * the lookup services started during construct.
  */
 public class DiscoveryBeginsOnSetGroupsAfterEmpty

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryBeginsOnSetGroupsAllAfterEmpty.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryBeginsOnSetGroupsAllAfterEmpty.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryBeginsOnSetGroupsAllAfterEmpty.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryBeginsOnSetGroupsAllAfterEmpty.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import net.jini.discovery.DiscoveryGroupManagement;
 
@@ -32,7 +33,7 @@ import net.jini.discovery.DiscoveryGroup
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *   <li> one or more initial lookup services, each belonging to a finite
  *        set of member groups, started during setup
  *   <li> an instance of the lookup discovery utility created by passing
  *        and empty String array (DiscoveryGroupManagement.NO_GROUPS) to
  *        the constructor
@@ -45,7 +46,7 @@ import net.jini.discovery.DiscoveryGroup
  * If the lookup discovery utility functions as specified, then the
  * listener will receive no events until the <code>setGroups</code> method
  * is called to re-configure the lookup discovery utility to discover
  * the lookup services started during setup.
  */
 public class DiscoveryBeginsOnSetGroupsAllAfterEmpty
                                   extends DiscoveryBeginsOnSetGroupsAfterEmpty
@@ -54,10 +55,11 @@ public class DiscoveryBeginsOnSetGroupsA
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         groupsToDiscover = DiscoveryGroupManagement.ALL_GROUPS;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class DiscoveryBeginsOnSetGroupsAllAfterEmpty
 
@@ -32,7 +33,7 @@ import net.jini.discovery.DiscoveryGroup
  * <p><ul>
  *   <li> one or more initial lookup services, each belonging to a finite
- *        set of member groups, started during setup
+ *        set of member groups, started during construct
  *   <li> an instance of the lookup discovery utility created by passing
  *        and empty String array (DiscoveryGroupManagement.NO_GROUPS) to
@@ -45,7 +46,7 @@ import net.jini.discovery.DiscoveryGroup
  * listener will receive no events until the <code>setGroups</code> method
  * is called to re-configure the lookup discovery utility to discover
- * the lookup services started during setup.
+ * the lookup services started during construct.
  */
 public class DiscoveryBeginsOnSetGroupsAllAfterEmpty

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryEndsOnTerminate.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/DiscoveryEndsOnTerminate.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorChange.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorChange.java Wed Jan  2 05:20:52 2013
@@ -18,10 +18,12 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
 import java.util.ArrayList;
+import java.util.List;
 
 /**
  * This class verifies that the <code>LookupDiscovery</code> utility
@@ -65,23 +67,24 @@ import java.util.ArrayList;
  */
 public class MulticastMonitorChange extends Discovered {
 
-    protected String[] replacementGroups = null;//null ==> generate new groups
-    protected boolean alternateReplacements = true;//some replaced, some not
+    protected volatile String[] replacementGroups = null;//null ==> generate new groups
+    protected volatile boolean alternateReplacements = true;//some replaced, some not
 
     /** Performs actions necessary to prepare for execution of the 
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         listenerToUse = new AbstractBaseTest.GroupChangeListener();
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
      *    <li> verifies the lookup discovery mechanism is functional by
      *         using group discovery to discover the lookup services
      *         started during setup
      *    <li> for alternating elements, replaces with a new group name,
      *         the member group elements of each of the discovered lookup
      *         services
@@ -100,7 +103,7 @@ public class MulticastMonitorChange exte
          * maps to change until setLookupsToDiscover returns.
          */
         synchronized(listenerToUse) {
-            ArrayList locGroupsPairList = null;
+            List locGroupsPairList = null;
             /* Replace groups with new groups to cause changed events */
             locGroupsPairList = replaceMemberGroups(alternateReplacements);
             /* Set the expected changed event info */
@@ -65,23 +67,24 @@ import java.util.ArrayList;
      *    <li> verifies the lookup discovery mechanism is functional by
      *         using group discovery to discover the lookup services
-     *         started during setup
+     *         started during construct
      *    <li> for alternating elements, replaces with a new group name,
      *         the member group elements of each of the discovered lookup

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorChange.td
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorChange.td?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorReplace.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorReplace.java Wed Jan  2 05:20:52 2013
@@ -18,12 +18,14 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
 import com.sun.jini.qa.harness.TestException;
 
 import java.util.ArrayList;
+import java.util.List;
 
 /**
  * This class verifies that the <code>LookupDiscovery</code> utility
@@ -70,16 +72,17 @@ public class MulticastMonitorReplace ext
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
-        nLookupsToReplace = genMap.size();//replace groups on all lookups
-    }//end setup
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
+        nLookupsToReplace = getGenMap().size();//replace groups on all lookups
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
      *    <li> verifies the lookup discovery mechanism is functional by
      *         using group discovery to discover the lookup services
      *         started during setup
      *    <li> replaces the member groups of each of the discovered lookup
      *         services with a new set that contains none of the elements
      *         from the set of groups the lookup discovery utility is
@@ -96,18 +99,18 @@ public class MulticastMonitorReplace ext
          * maps to change until setLookupsToDiscover returns.
          */
         synchronized(listenerToUse) {
-            ArrayList locGroupsPairList = null;
+            List locGroupsPairList = null;
             /* Replace current groups with new groups to cause discards */
             if(replacementGroups == null) {//use unique generated groups
                 locGroupsPairList = replaceMemberGroups();
-            } else {//use groups preset in setup
+            } else {//use groups preset in construct
                 locGroupsPairList = replaceMemberGroups(nLookupsToReplace,
                                                         replacementGroups);
             }//endif
             /* Set the expected discard event info */
             listenerToUse.setLookupsToDiscover
                                      (locGroupsPairList,
-                                      toGroupsArray(initLookupsToStart));
+                                      toGroupsArray(getInitLookupsToStart()));
         }//end sync(listenerToUse)
         waitForDiscard(listenerToUse);
     }//end run
@@ -70,16 +72,17 @@ public class MulticastMonitorReplace ext
      *    <li> verifies the lookup discovery mechanism is functional by
      *         using group discovery to discover the lookup services
-     *         started during setup
+     *         started during construct
      *    <li> replaces the member groups of each of the discovered lookup
      *         services with a new set that contains none of the elements

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorReplaceNone.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/MulticastMonitorReplaceNone.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsDups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsDups.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -36,7 +37,7 @@ import java.util.ArrayList;
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *   <li> one or more lookup services, each belonging to a finite
  *        set of member groups, and each started during setup, before the
  *        test begins execution
  *   <li> one instance of the lookup discovery utility configured to discover
  *        the set of groups whose elements are the member groups of the
@@ -63,8 +64,8 @@ public class RemoveGroupsDups extends Re
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	int len1 = groupsToRemove.length;
 	int len2 = 2*len1;
 	ArrayList dupGroupsList = new ArrayList(len2);
@@ -76,7 +77,8 @@ public class RemoveGroupsDups extends Re
 	}//end loop
 	groupsToRemove = (String[])(dupGroupsList).toArray
 	    (new String[dupGroupsList.size()]);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class RemoveGroupsDups
 
@@ -36,7 +37,7 @@ import java.util.ArrayList;
  * <p><ul>
  *   <li> one or more lookup services, each belonging to a finite
- *        set of member groups, and each started during setup, before the
+ *        set of member groups, and each started during construct, before the
  *        test begins execution
  *   <li> one instance of the lookup discovery utility configured to discover

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsNullElement.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsNullElement.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsRemoveAll.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsRemoveAll.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 /**
  * With respect to the <code>removeGroups</code> method, this class
@@ -35,7 +36,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *   <li> one or more lookup services, each belonging to a finite
  *        set of member groups, and each started during setup, before the
  *        test begins execution
  *   <li> one instance of the lookup discovery utility configured to discover
  *        the set of groups whose elements are the member groups of the
@@ -56,9 +57,10 @@ public class RemoveGroupsRemoveAll exten
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         changeAll = true;
-        super.setup(sysConfig);
-    }//end setup
+        super.construct(sysConfig);
+        return this;
+    }//end construct
 
 }//end class RemoveGroupsRemoveAll
@@ -35,7 +36,7 @@ import com.sun.jini.qa.harness.QAConfig;
  * <p><ul>
  *   <li> one or more lookup services, each belonging to a finite
- *        set of member groups, and each started during setup, before the
+ *        set of member groups, and each started during construct, before the
  *        test begins execution
  *   <li> one instance of the lookup discovery utility configured to discover

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsRemoveNone.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsRemoveNone.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsRemoveSome.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsRemoveSome.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -26,6 +27,7 @@ import com.sun.jini.test.share.GroupsUti
 import net.jini.discovery.DiscoveryGroupManagement;
 
 import java.util.ArrayList;
+import java.util.List;
 
 /**
  * With respect to the <code>removeGroups</code> method, this class
@@ -42,7 +44,7 @@ import java.util.ArrayList;
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *   <li> one or more lookup services, each belonging to a finite
  *        set of member groups, and each started during setup, before the
  *        test begins execution
  *   <li> one instance of the lookup discovery utility configured to discover
  *        the set of groups whose elements are the member groups of the
@@ -59,10 +61,10 @@ import java.util.ArrayList;
  */
 public class RemoveGroupsRemoveSome extends Discovered {
 
-    protected ArrayList curLookupsToDiscover = initLookupsToStart;
-    protected ArrayList newLookupsToDiscover = new ArrayList(11);
-    protected ArrayList lookupsToRemoveList = new ArrayList(11);
-    protected String[]  groupsToRemove = DiscoveryGroupManagement.NO_GROUPS;
+    protected volatile List curLookupsToDiscover = new ArrayList(0);
+    protected final List newLookupsToDiscover = new ArrayList(11);
+    protected final List lookupsToRemoveList = new ArrayList(11);
+    protected volatile String[]  groupsToRemove = DiscoveryGroupManagement.NO_GROUPS;
 
     protected boolean changeAll = false;
 
@@ -70,8 +72,9 @@ public class RemoveGroupsRemoveSome exte
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
+        curLookupsToDiscover = getInitLookupsToStart();
 	/* Remove the groups for the lookup services at an even index.
 	 * Remove groups at an odd index as well if changeAll is true.
 	 */
@@ -79,7 +82,7 @@ public class RemoveGroupsRemoveSome exte
 	    LocatorGroupsPair curPair =
 		(LocatorGroupsPair)curLookupsToDiscover.get(i);
 	    if( ((i%2) == 0) || changeAll ) {//index is even or changeAll
-		String[] curGroups = curPair.groups;
+		String[] curGroups = curPair.getGroups();
 		if(    (curGroups != DiscoveryGroupManagement.ALL_GROUPS)
 		       && (curGroups.length != 0) )
                     {
@@ -93,12 +96,13 @@ public class RemoveGroupsRemoveSome exte
 	}//end loop
 	groupsToRemove =(String[])(lookupsToRemoveList).toArray
 	    (new String[lookupsToRemoveList.size()]);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
      *    <li> re-configures the lookup discovery utility to use group 
      *         discovery to discover the lookup services started during setup
      *    <li> starts the multicast discovery process by adding a discovery
      *         listener to the lookup discovery utility
      *    <li> verifies that the discovery process is working by waiting
@@ -42,7 +44,7 @@ import java.util.ArrayList;
  * <p><ul>
  *   <li> one or more lookup services, each belonging to a finite
- *        set of member groups, and each started during setup, before the
+ *        set of member groups, and each started during construct, before the
  *        test begins execution
  *   <li> one instance of the lookup discovery utility configured to discover
@@ -93,12 +96,13 @@ public class RemoveGroupsRemoveSome exte
      * <p><ul>
      *    <li> re-configures the lookup discovery utility to use group 
-     *         discovery to discover the lookup services started during setup
+     *         discovery to discover the lookup services started during construct
      *    <li> starts the multicast discovery process by adding a discovery
      *         listener to the lookup discovery utility

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsUnsupportedOperation.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/RemoveGroupsUnsupportedOperation.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsAllGroups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsAllGroups.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -35,7 +36,7 @@ import net.jini.discovery.DiscoveryGroup
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *   <li> one or more lookup services, each belonging to a finite
  *        set of member groups, and each started during setup, before the
  *        test begins execution
  *   <li> one instance of the lookup discovery utility initially configured
  *        to discover NO_GROUPS
@@ -57,10 +58,11 @@ public class SetGroupsAllGroups extends 
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
         groupsToDiscover = DiscoveryGroupManagement.ALL_GROUPS;
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class SetGroupsAllGroups
 
@@ -35,7 +36,7 @@ import net.jini.discovery.DiscoveryGroup
  * <p><ul>
  *   <li> one or more lookup services, each belonging to a finite
- *        set of member groups, and each started during setup, before the
+ *        set of member groups, and each started during construct, before the
  *        test begins execution
  *   <li> one instance of the lookup discovery utility initially configured

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsDups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsDups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsDups.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsDups.java Wed Jan  2 05:20:52 2013
@@ -18,6 +18,7 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -36,7 +37,7 @@ import java.util.ArrayList;
  * The environment in which this class expects to operate is as follows:
  * <p><ul>
  *   <li> one or more lookup services, each belonging to a finite
  *        set of member groups, and each started during setup, before the
  *        test begins execution
  *   <li> one instance of the lookup discovery utility configured to discover
  *        the set of groups whose elements are the member groups of the
@@ -63,8 +64,8 @@ public class SetGroupsDups extends SetGr
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
 	int len1 = newGroupsToDiscover.length;
 	int len2 = 2*len1;
 	ArrayList dupGroupsList = new ArrayList(len2);
@@ -76,7 +77,8 @@ public class SetGroupsDups extends SetGr
 	}//end loop
 	newGroupsToDiscover = (String[])(dupGroupsList).toArray
 	    (new String[dupGroupsList.size()]);
-    }//end setup
+        return this;
+    }//end construct
 
 }//end class SetGroupsDups
 
@@ -36,7 +37,7 @@ import java.util.ArrayList;
  * <p><ul>
  *   <li> one or more lookup services, each belonging to a finite
- *        set of member groups, and each started during setup, before the
+ *        set of member groups, and each started during construct, before the
  *        test begins execution
  *   <li> one instance of the lookup discovery utility configured to discover

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsNoGroups.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsNoGroups.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsReplaceSome.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupdiscovery/SetGroupsReplaceSome.java Wed Jan  2 05:20:52 2013
@@ -18,10 +18,12 @@
 
 package com.sun.jini.test.spec.lookupdiscovery;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
 import java.util.ArrayList;
+import java.util.List;
 
 /**
  * With respect to the <code>setGroups</code> method, this class verifies
@@ -52,7 +54,7 @@ import java.util.ArrayList;
  */
 public class SetGroupsReplaceSome extends Discovered {
 
-    protected ArrayList oldLookupsToDiscover = null;
+    protected List oldLookupsToDiscover = null;
     protected String[] newGroupsToDiscover = new String[] {"SetGroups_newSet"};
 
     protected boolean changeAll = false;
@@ -61,8 +63,8 @@ public class SetGroupsReplaceSome extend
      *  current test (refer to the description of this method in the
      *  parent class).
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-        super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+        super.construct(sysConfig);
 	oldLookupsToDiscover = locGroupsList;
 	ArrayList newGroupsList = new ArrayList(11);
 	/* Change the groups to discover for the lookup services at an
@@ -72,7 +74,7 @@ public class SetGroupsReplaceSome extend
 	for(int i=0;i<oldLookupsToDiscover.size();i++) {
 	    LocatorGroupsPair oldPair =
 		(LocatorGroupsPair)oldLookupsToDiscover.get(i);
-	    String[] oldGroups = oldPair.groups;
+	    String[] oldGroups = oldPair.getGroups();
 	    String[] newGroups = oldGroups;
 	    if( ((i%2) == 0) || changeAll ) {//index is even or changeAll
 		if(oldGroups.length == 0) {
@@ -90,12 +92,13 @@ public class SetGroupsReplaceSome extend
 	}//end loop
 	newGroupsToDiscover =(String[])(newGroupsList).toArray
 	    (new String[newGroupsList.size()]);
-    }//end setup
+        return this;
+    }//end construct
 
     /** Executes the current test by doing the following:
      * <p><ul>
      *    <li> re-configures the lookup discovery utility to use group 
      *         discovery to discover the lookup services started during setup
      *    <li> starts the multicast discovery process by adding a discovery
      *         listener to the lookup discovery utility
      *    <li> verifies that the discovery process is working by waiting
@@ -90,12 +92,13 @@ public class SetGroupsReplaceSome extend
      * <p><ul>
      *    <li> re-configures the lookup discovery utility to use group 
-     *         discovery to discover the lookup services started during setup
+     *         discovery to discover the lookup services started during construct
      *    <li> starts the multicast discovery process by adding a discovery
      *         listener to the lookup discovery utility

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/QATestRegistrar.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/QATestRegistrar.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/QATestRegistrar.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/QATestRegistrar.java Wed Jan  2 05:20:52 2013
@@ -42,7 +42,7 @@ import java.util.List;
 import java.util.HashMap;
 import java.util.logging.Level;
 import com.sun.jini.qa.harness.QAConfig;
-import com.sun.jini.qa.harness.QATest;
+import com.sun.jini.qa.harness.QATestEnvironment;
 import com.sun.jini.qa.harness.ActivatableServiceStarterAdmin;
 
 import net.jini.config.Configuration;
@@ -53,18 +53,19 @@ import net.jini.security.TrustVerifier;
 import net.jini.security.proxytrust.ServerProxyTrust;
 
 import com.sun.jini.proxy.BasicProxyTrustVerifier;
+import com.sun.jini.qa.harness.Test;
 
 import com.sun.jini.qa.harness.TestException;
 
 /** Besides providing implementations for the abstract methods of the 
  *  super class (QATest), this class is the common super class of 
  *  all QA test classes of the Lookup component of the Jini System. 
  *  This class encapsulates shared data and methods on behalf of each 
  *  of those test classes.
  *
- *  @see com.sun.jini.qa.harness.QATest
+ *  @see com.sun.jini.qa.harness.QATestEnvironment
  */
-public abstract class QATestRegistrar extends QATest {
+public abstract class QATestRegistrar extends QATestEnvironment implements Test {
 
     /** The default codebase for the RMI sub-system */
     private final static String DEF_RMI_CODEBASE 
@@ -334,9 +335,9 @@ public abstract class QATestRegistrar ex
         return (String[])(stringList.toArray(new String[stringList.size()]));
     }
 
     /** After performing high-level setup by invoking the setup() method
      *  in the super class (QATest), this method will perform mid-level,
      *  general-purpose setup actions necessary to prepare for execution of 
      *  the current QA test.
      *
      *  This method parses the argument list to retrieve and process the
@@ -355,11 +356,11 @@ public abstract class QATestRegistrar ex
      *  @exception TestException will usually indicate an "unresolved"
      *  condition because at this point the test has not yet begun.
      */
-    public void setup(QAConfig config) throws Exception {
+    public Test construct(QAConfig config) throws Exception {
 	int i,j;
 	int index;
 
-	super.setup(config);
+	super.construct(config);
 
 	logger.log(Level.FINE, "QATestRegistrar : in setup() method.");
 
@@ -467,10 +468,11 @@ public abstract class QATestRegistrar ex
         getSetupInfo();
 
 	// Receive Lookup proxy
-	proxy = manager.startLookupService();
+	proxy = getManager().startLookupService();
 	// Receive admin proxy fro Lookup
 	adminProxy = ((Administrable)proxy).getAdmin();
 	adminProxy = config.prepare("test.reggieAdminPreparer",adminProxy);
+        return this;
     }
  
     /* Retrieve (and display) configuration values for the current test */
@@ -491,32 +493,32 @@ public abstract class QATestRegistrar ex
         /* begin service info */
         logger.log(Level.FINE,
                           "----- ServiceRegistrar Service Info ----- ");
-        String serviceImplClassname = config.getStringConfigVal
+        String serviceImplClassname = getConfig().getStringConfigVal
                                                          (serviceName+".impl",
                                                           "no implClassname");
         logger.log(Level.FINE, "service impl class     -- "
                                         +serviceImplClassname);
 
-        String serviceCobaseArg = config.getStringConfigVal
+        String serviceCobaseArg = getConfig().getStringConfigVal
                                                      (serviceName+".codebase",
                                                       "no codebase");
         String serviceCodebase = serviceCobaseArg;
         logger.log(Level.FINE, "service codebase       -- "
                                         +serviceCodebase);
 
-        String serviceClasspath = config.getStringConfigVal
+        String serviceClasspath = getConfig().getStringConfigVal
                                                    (serviceName+".classpath",
                                                     "no classpath");
         logger.log(Level.FINE, "service classpath      -- "
                                         +serviceClasspath);
 
-        String servicePolicyFile = config.getStringConfigVal
+        String servicePolicyFile = getConfig().getStringConfigVal
                                                  (serviceName+".policyfile",
                                                   "no policyFile");
         logger.log(Level.FINE, "service policy file    -- "
                                         +servicePolicyFile);
 
-        int nInstances = config.getIntConfigVal(serviceName+".instances", 1);
+        int nInstances = getConfig().getIntConfigVal(serviceName+".instances", 1);
         logger.log(Level.FINE, "# of service instances -- "
                                         +nInstances);
         /* end service info */
@@ -973,7 +975,7 @@ public abstract class QATestRegistrar ex
                                                          throws Exception
     {
 	Object reg = regProxy.register(srvcItem,Long.MAX_VALUE);
-	reg = config.prepare("test.reggieServiceRegistrationPreparer", reg);
+	reg = getConfig().prepare("test.reggieServiceRegistrationPreparer", reg);
 	return (ServiceRegistration) reg;
     }
 
@@ -994,7 +996,7 @@ public abstract class QATestRegistrar ex
                                                          throws Exception
     {
 	Object reg = regProxy.register(srvcItem,srvcLeaseDurMS);
-	reg = config.prepare("test.reggieServiceRegistrationPreparer", reg);
+	reg = getConfig().prepare("test.reggieServiceRegistrationPreparer", reg);
 	return (ServiceRegistration) reg;
     }
 
@@ -1006,7 +1008,7 @@ public abstract class QATestRegistrar ex
 
     protected Lease prepareRegistrationLease(Lease lease) throws Exception {
 	return (Lease) 
-	       config.prepare("test.reggieServiceLeasePreparer", lease);
+	       getConfig().prepare("test.reggieServiceLeasePreparer", lease);
     }
 
     protected LeaseMap prepareRegistrationLeaseMap(LeaseMap leaseMap) {
@@ -1017,7 +1019,7 @@ public abstract class QATestRegistrar ex
     protected Lease getEventLease(EventRegistration reg) throws Exception {
 	    Lease lease = reg.getLease();
 	    return (Lease) 
-		   config.prepare("test.reggieEventLeasePreparer", lease);
+		   getConfig().prepare("test.reggieEventLeasePreparer", lease);
     }
 
     //XXX can exception handling be any smarter?
@@ -1025,7 +1027,7 @@ public abstract class QATestRegistrar ex
 	throws Exception
     {
 	return (EventRegistration) 
-	       config.prepare("test.reggieEventRegistrationPreparer", reg);
+	       getConfig().prepare("test.reggieEventRegistrationPreparer", reg);
     }
 
     protected Object exportListener(RemoteEventListener listener) 
@@ -1034,7 +1036,7 @@ public abstract class QATestRegistrar ex
 	// wrap a configuration exception in a RemoteException to avoid having
 	// to redefine the constructors for a million subclasses of BasicListener
 	Exporter exporter = QAConfig.getDefaultExporter();
-	Configuration c = config.getConfiguration();
+	Configuration c = getConfig().getConfiguration();
 	if (c instanceof com.sun.jini.qa.harness.QAConfiguration) {
 	    try {
 		exporter = (Exporter) c.getEntry("test",
@@ -53,18 +53,19 @@ import net.jini.security.TrustVerifier;
 
 /** Besides providing implementations for the abstract methods of the 
- *  super class (QATest), this class is the common super class of 
+ *  super class (QATestEnvironment), this class is the common super class of 
  *  all QA test classes of the Lookup component of the Jini System. 
  *  This class encapsulates shared data and methods on behalf of each 
@@ -334,9 +335,9 @@ public abstract class QATestRegistrar ex
     }
 
-    /** After performing high-level setup by invoking the setup() method
-     *  in the super class (QATest), this method will perform mid-level,
-     *  general-purpose setup actions necessary to prepare for execution of 
+    /** After performing high-level construct by invoking the construct() method
+     *  in the super class (QATestEnvironment), this method will perform mid-level,
+     *  general-purpose construct actions necessary to prepare for execution of 
      *  the current QA test.
      *

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/QATestUtils.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/QATestUtils.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/ToStringTest.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/ToStringTest.java Wed Jan  2 05:20:52 2013
@@ -26,22 +26,24 @@ import net.jini.core.lookup.ServiceItem;
 import net.jini.core.lookup.ServiceMatches;
 import net.jini.core.lookup.ServiceTemplate;
 
-import com.sun.jini.qa.harness.Test;
+import com.sun.jini.qa.harness.LegacyTest;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 
 /**
  * Test that verifies that toString() methods of ServiceItem,
  * ServiceMatches, and ServiceTemplate can handle null values,
  * 0-length arrays, and arrays with null elements.
  * 
  */
-public class ToStringTest implements Test {
+public class ToStringTest implements LegacyTest {
 
     private QAConfig config = null;
 
-    public void setup(QAConfig config) {
+    public Test construct(QAConfig config) {
         this.config = config;
+        return this;
     }
 
     public void run() throws Exception {
@@ -26,22 +26,24 @@ import net.jini.core.lookup.ServiceItem;
 
 /**
- * Test that verifies that toString() methods of ServiceItem,
+ * LegacyTest that verifies that toString() methods of ServiceItem,
  * ServiceMatches, and ServiceTemplate can handle null values,
  * 0-length arrays, and arrays with null elements.

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/EvntLeaseExpiration.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/EvntLeaseExpiration.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupByClass.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupByClass.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set00;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -56,8 +57,8 @@ public class LookupByClass extends QATes
      *  which each element contains the class type of one of the registered
      *  services.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
-	super.setup(sysConfig);
+    public Test construct(QAConfig sysConfig) throws Exception {
+	super.construct(sysConfig);
         nClasses = super.getNTestClasses();
         nInstances = super.getNInstances();
         nInstancesPerClass = super.getNInstancesPerClass();
@@ -71,13 +72,14 @@ public class LookupByClass extends QATes
 	    exactClassTmpls[i] = new ServiceTemplate(null,
 						     exactClassType,null);
 	}
+        return this;
     }
 
     /** Executes the current QA test.
      *
      *  For each service registered:  
      *      Performs a match lookup using the corresponding template 
      *      created during setup and then tests that the number of matches
      *      found equals the number of matches expected; and that the set
      *      of objects returned equals the expected set of corresponding
      *      service items.
@@ -71,13 +72,14 @@ public class LookupByClass extends QATes
      *  For each service registered:  
      *      Performs a match lookup using the corresponding template 
-     *      created during setup and then tests that the number of matches
+     *      created during construct and then tests that the number of matches
      *      found equals the number of matches expected; and that the set
      *      of objects returned equals the expected set of corresponding

Modified: river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupByIntfc.java
URL: http://svn.apache.org/viewvc/river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupByIntfc.java?rev=1427655&r1=1427654&r2=1427655&view=diff
==============================================================================
--- river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupByIntfc.java (original)
+++ river/jtsk/skunk/qa_refactor/trunk/qa/src/com/sun/jini/test/spec/lookupservice/test_set00/LookupByIntfc.java Wed Jan  2 05:20:52 2013
@@ -17,6 +17,7 @@
  */
 package com.sun.jini.test.spec.lookupservice.test_set00;
 import com.sun.jini.qa.harness.QAConfig;
+import com.sun.jini.qa.harness.Test;
 
 import java.util.logging.Level;
 
@@ -59,13 +60,13 @@ public class LookupByIntfc extends QATes
      *  which each element contains one of the interfaces, implemented
      *  by the corresponding service, from the set of test interfaces.
      */
-    public void setup(QAConfig sysConfig) throws Exception {
+    public Test construct(QAConfig sysConfig) throws Exception {
         int i,j,k;
         int indx;
         Class sClass;
         Class iClass[] = new Class[super.INTERFACES.length];
 
-        super.setup(sysConfig); 
+        super.construct(sysConfig); 
 
 	logger.log(Level.FINE, "in setup() method.");
 
@@ -102,6 +103,7 @@ public class LookupByIntfc extends QATes
 		}
 	    }
 	}
+        return this;
     }
 
     /** Executes the current QA test.
@@ -109,7 +111,7 @@ public class LookupByIntfc extends QATes
      *  For each registered service:  
      *     For each interface in the set of test interfaces:  
      *        Performs a match lookup using the corresponding template 
      *        created during setup and then tests that the number of matches
      *        found equals the number of matches expected; and that the set
      *        of objects returned equals the expected set of corresponding
      *        service items.
@@ -109,7 +111,7 @@ public class LookupByIntfc extends QATes
      *     For each interface in the set of test interfaces:  
      *        Performs a match lookup using the corresponding template 
-     *        created during setup and then tests that the number of matches
+     *        created during construct and then tests that the number of matches
      *        found equals the number of matches expected; and that the set
      *        of objects returned equals the expected set of corresponding